@@ -1,6 +1,6 @@
 package Bencher::ScenarioR::DataComparisonModules::Compare;
 
-our $VERSION = 0.002; # VERSION
+our $VERSION = 0.003; # VERSION
 
 our $results = [
   [
@@ -8,139 +8,229 @@ our $results = [
     "OK",
     [
       {
-        dataset     => "hash keys=1000",
-        errors      => 1.6e-05,
-        participant => "Data::Compare::Compare",
-        rate        => 220,
+        dataset     => "array len=1000",
+        errors      => 1.4e-05,
+        participant => "Data::Diff::diff",
+        rate        => 160,
         samples     => 20,
-        time        => 4.6,
+        time        => 6.2,
         vs_slowest  => 1,
       },
       {
-        dataset     => "array len=1000",
-        errors      => 4.2e-06,
-        participant => "Data::Compare::Compare",
-        rate        => 300,
-        samples     => 21,
-        time        => 3.3,
-        vs_slowest  => 1.4,
+        dataset     => "hash keys=1000",
+        errors      => 6.5e-06,
+        participant => "Data::Comparator::data_comparator",
+        rate        => 190,
+        samples     => 20,
+        time        => 5.1,
+        vs_slowest  => 1.2,
       },
       {
         dataset     => "hash keys=1000",
-        errors      => 8.3e-06,
-        participant => "Test::Deep::NoTest::eq_deeply",
-        rate        => 380,
+        errors      => 6.9e-06,
+        participant => "Data::Diff::diff",
+        rate        => 190,
         samples     => 20,
-        time        => 2.6,
+        time        => 5.1,
+        vs_slowest  => 1.2,
+      },
+      {
+        dataset     => "hash keys=1000",
+        errors      => 4e-06,
+        participant => "Data::Compare::Compare",
+        rate        => 209,
+        samples     => 20,
+        time        => 4.78,
+        vs_slowest  => 1.29,
+      },
+      {
+        dataset     => "array len=1000",
+        errors      => 9.4e-06,
+        participant => "Data::Comparator::data_comparator",
+        rate        => 220,
+        samples     => 21,
+        time        => 4.6,
+        vs_slowest  => 1.3,
+      },
+      {
+        dataset     => "array len=1000",
+        errors      => 6.1e-06,
+        participant => "Data::Compare::Compare",
+        rate        => 290,
+        samples     => 20,
+        time        => 3.4,
         vs_slowest  => 1.8,
       },
       {
         dataset     => "hash keys=1000",
-        errors      => 3.1e-06,
-        participant => "Data::Cmp::cmp_data",
-        rate        => 640,
+        errors      => 4.2e-06,
+        participant => "Test::Deep::NoTest::eq_deeply",
+        rate        => 370,
         samples     => 20,
-        time        => 1.6,
-        vs_slowest  => 2.9,
+        time        => 2.7,
+        vs_slowest  => 2.3,
       },
       {
-        dataset     => "array len=1000",
+        dataset     => "hash keys=1000",
         errors      => 4.1e-06,
         participant => "Data::Cmp::cmp_data",
-        rate        => 1000,
+        rate        => 620,
         samples     => 20,
-        time        => 0.97,
-        vs_slowest  => 4.7,
+        time        => 1.6,
+        vs_slowest  => 3.8,
       },
       {
         dataset     => "array len=1000",
-        errors      => 2.2e-06,
+        errors      => 2.8e-06,
+        participant => "Data::Cmp::cmp_data",
+        rate        => 1000,
+        samples     => 25,
+        time        => 0.96,
+        vs_slowest  => 6.4,
+      },
+      {
+        dataset     => "array len=1000",
+        errors      => 5.9e-06,
         participant => "Test::Deep::NoTest::eq_deeply",
-        rate        => 1400,
+        rate        => 1300,
         samples     => 21,
-        time        => 0.69,
-        vs_slowest  => 6.6,
+        time        => 0.74,
+        vs_slowest  => 8.3,
       },
       {
         dataset     => "hash keys=10",
-        errors      => 2.6e-07,
+        errors      => 2.7e-07,
         participant => "Test::Deep::NoTest::eq_deeply",
-        rate        => 6500,
-        samples     => 21,
-        time        => 0.15,
-        vs_slowest  => 30,
-      },
-      {
-        dataset     => "array len=10",
-        errors      => 2.1e-07,
-        participant => "Test::Deep::NoTest::eq_deeply",
-        rate        => 8400,
+        rate        => 6100,
         samples     => 20,
-        time        => 0.12,
+        time        => 0.16,
         vs_slowest  => 38,
       },
       {
-        dataset     => "hash keys=10",
-        errors      => 9.5e-08,
-        participant => "Data::Compare::Compare",
-        rate        => 17000,
+        dataset     => "array len=10",
+        errors      => 2.4e-07,
+        participant => "Test::Deep::NoTest::eq_deeply",
+        rate        => 8200,
         samples     => 25,
-        time        => 0.058,
-        vs_slowest  => 80,
+        time        => 0.12,
+        vs_slowest  => 50,
       },
       {
         dataset     => "array len=10",
-        errors      => 1.3e-08,
+        errors      => 1.1e-07,
+        participant => "Data::Diff::diff",
+        rate        => 14000,
+        samples     => 20,
+        time        => 0.069,
+        vs_slowest  => 89,
+      },
+      {
+        dataset     => "hash keys=10",
+        errors      => 1.1e-07,
+        participant => "Data::Comparator::data_comparator",
+        rate        => 18000,
+        samples     => 20,
+        time        => 0.057,
+        vs_slowest  => 110,
+      },
+      {
+        dataset     => "hash keys=10",
+        errors      => 1e-07,
+        participant => "Data::Diff::diff",
+        rate        => 18000,
+        samples     => 22,
+        time        => 0.054,
+        vs_slowest  => 110,
+      },
+      {
+        dataset     => "hash keys=10",
+        errors      => 1.2e-07,
         participant => "Data::Compare::Compare",
-        rate        => 25600,
+        rate        => 18000,
+        samples     => 25,
+        time        => 0.054,
+        vs_slowest  => 110,
+      },
+      {
+        dataset     => "array len=10",
+        errors      => 1.1e-07,
+        participant => "Data::Comparator::data_comparator",
+        rate        => 19000,
+        samples     => 20,
+        time        => 0.052,
+        vs_slowest  => 120,
+      },
+      {
+        dataset     => "array len=10",
+        errors      => 5.2e-08,
+        participant => "Data::Compare::Compare",
+        rate        => 26000,
         samples     => 21,
-        time        => 0.039,
-        vs_slowest  => 118,
+        time        => 0.038,
+        vs_slowest  => 160,
       },
       {
         dataset     => "hash keys=10",
         errors      => 2.7e-08,
         participant => "Data::Cmp::cmp_data",
-        rate        => 64000,
+        rate        => 63000,
         samples     => 20,
         time        => 0.016,
-        vs_slowest  => 290,
+        vs_slowest  => 390,
       },
       {
         dataset     => "array len=10",
-        errors      => 1.2e-08,
+        errors      => 5.5e-09,
         participant => "Data::Cmp::cmp_data",
-        rate        => 87000,
-        samples     => 26,
-        time        => 0.012,
-        vs_slowest  => 400,
+        rate        => 78300,
+        samples     => 29,
+        time        => 0.0128,
+        vs_slowest  => 482,
+      },
+      {
+        dataset     => "simple scalar",
+        errors      => 1.6e-09,
+        participant => "Test::Deep::NoTest::eq_deeply",
+        rate        => 167000,
+        samples     => 22,
+        time        => 0.00597,
+        vs_slowest  => 1030,
+      },
+      {
+        dataset     => "simple scalar",
+        errors      => 4.5e-11,
+        participant => "Data::Diff::diff",
+        rate        => 216980,
+        samples     => 21,
+        time        => 0.0046087,
+        vs_slowest  => 1336,
       },
       {
         dataset     => "simple scalar",
         errors      => 1.7e-09,
-        participant => "Test::Deep::NoTest::eq_deeply",
-        rate        => 174000,
+        participant => "Data::Comparator::data_comparator",
+        rate        => 311000,
         samples     => 20,
-        time        => 0.00576,
-        vs_slowest  => 796,
+        time        => 0.00322,
+        vs_slowest  => 1910,
       },
       {
         dataset     => "simple scalar",
-        errors      => 2.8e-09,
+        errors      => 4.1e-09,
         participant => "Data::Compare::Compare",
-        rate        => 450000,
-        samples     => 28,
-        time        => 0.0022,
-        vs_slowest  => 2000,
+        rate        => 440000,
+        samples     => 21,
+        time        => 0.0023,
+        vs_slowest  => 2700,
       },
       {
         dataset     => "simple scalar",
-        errors      => 4.7e-09,
+        errors      => 2.7e-09,
         participant => "Data::Cmp::cmp_data",
         rate        => 1100000,
-        samples     => 23,
-        time        => 0.00087,
-        vs_slowest  => 5300,
+        samples     => 24,
+        time        => 0.00092,
+        vs_slowest  => 6700,
       },
     ],
     {
@@ -265,7 +355,7 @@ our $results = [
                                               number_of_cores              => 2,
                                               number_of_logical_processors => 4,
                                               processor_id                 => 0,
-                                              speed                        => 2593.811,
+                                              speed                        => 2833.496,
                                               stepping                     => 4,
                                             },
                                             {
@@ -381,7 +471,7 @@ our $results = [
                                               number_of_cores              => 2,
                                               number_of_logical_processors => 4,
                                               processor_id                 => 1,
-                                              speed                        => 2472.644,
+                                              speed                        => 2525.366,
                                               stepping                     => 4,
                                             },
                                             {
@@ -497,7 +587,7 @@ our $results = [
                                               number_of_cores              => 2,
                                               number_of_logical_processors => 4,
                                               processor_id                 => 2,
-                                              speed                        => 2779.577,
+                                              speed                        => 2717.541,
                                               stepping                     => 4,
                                             },
                                             {
@@ -613,25 +703,34 @@ our $results = [
                                               number_of_cores              => 2,
                                               number_of_logical_processors => 4,
                                               processor_id                 => 3,
-                                              speed                        => 2588.598,
+                                              speed                        => 2741.552,
                                               stepping                     => 4,
                                             },
                                           ],
-      "func.elapsed_time"              => 0.657371044158936,
+      "func.elapsed_time"              => 1.41306090354919,
       "func.module_startup"            => undef,
       "func.module_versions"           => {
-                                            "__PACKAGE__" => 1.041,
+                                            "__PACKAGE__"                                       => 1.041,
                                             "Bencher::Scenario::DataComparisonModules::Compare" => undef,
-                                            "Benchmark::Dumb" => 0.111,
-                                            "Data::Cmp" => 0.002,
-                                            "Data::Compare" => 1.25,
-                                            "Devel::Platform::Info" => 0.16,
-                                            "perl" => "v5.26.1",
-                                            "Sys::Info" => 0.78,
-                                            "Test::Deep::NoTest" => undef,
+                                            "Benchmark::Dumb"                                   => 0.111,
+                                            "Data::Cmp"                                         => 0.003,
+                                            "Data::Comparator"                                  => undef,
+                                            "Data::Compare"                                     => 1.25,
+                                            "Data::Diff"                                        => 0.01,
+                                            "Devel::Platform::Info"                             => 0.16,
+                                            "perl"                                              => "v5.26.1",
+                                            "Sys::Info"                                         => 0.78,
+                                            "Test::Deep::NoTest"                                => undef,
                                           },
       "func.note"                      => "Run by Pod::Weaver::Plugin::Bencher::Scenario",
-      "func.permute"                   => ["perl", ["perl"], "participant", [0, 1, 2], "dataset", [0 .. 4]],
+      "func.permute"                   => [
+                                            "perl",
+                                            ["perl"],
+                                            "participant",
+                                            [0 .. 4],
+                                            "dataset",
+                                            [0, 1, 2, 4, 5],
+                                          ],
       "func.platform_info"             => {
                                             archname => "x86_64",
                                             codename => "sylvia",
@@ -657,13 +756,13 @@ our $results = [
                                           },
       "func.precision"                 => 0,
       "func.scenario_module"           => "Bencher::Scenario::DataComparisonModules::Compare",
-      "func.scenario_module_md5sum"    => "af689f2d40a7985cb595419ef34a7bfd",
-      "func.scenario_module_mtime"     => 1534033084,
-      "func.scenario_module_sha1sum"   => "d1ba6929e617ba63df9915bbffe73d3d1173a8af",
-      "func.scenario_module_sha256sum" => "2ef1dd5ab4cb3174f25374b2c3f2c458233d9c452a8a8b4c2028b9dd08762508",
-      "func.time_end"                  => 1534033119.01409,
+      "func.scenario_module_md5sum"    => "ccacde56f0b4862d35ca4269cb723634",
+      "func.scenario_module_mtime"     => 1534068588,
+      "func.scenario_module_sha1sum"   => "1576667af9b25b47ec1345caa4d016834acf8d8f",
+      "func.scenario_module_sha256sum" => "be561aa373d38659fa73db9185c23eb4065687283df32f0e09822bcd80fc6cbc",
+      "func.time_end"                  => 1534069423.04905,
       "func.time_factor"               => 1000,
-      "func.time_start"                => 1534033118.35671,
+      "func.time_start"                => 1534069421.63599,
       "table.field_aligns"             => ["left", "left", "number", "number", "number", "number", "number"],
       "table.field_units"              => [undef, undef, "/s", "ms"],
       "table.fields"                   => [
